@@ -116,6 +116,7 @@ class CLIParser:
         )
         parser.add_argument(
             "--no-format",
+            "--nf",
             action="store_true",
             required=False,
             help="disable colouring and text wrapping in command output",
@@ -1051,6 +1052,13 @@ class CLIParser:
                 required=False,
                 help="display the worker pool token when showing the details of a configured worker pool",
             )
+            parser.add_argument(
+                "--add-resource-property",
+                "-a",
+                action="store_true",
+                required=False,
+                help="Add the 'resource' property when showing the JSON details of an object",
+            )
 
         self.args = parser.parse_args()
 
@@ -1522,6 +1530,11 @@ class CLIParser:
     def show_token(self) -> Optional[bool]:
         return self.args.show_token
 
+    @property
+    @allow_missing_attribute
+    def add_resource_property(self) -> Optional[bool]:
+        return self.args.add_resource_property
+
 
 def lookup_module_description(module_name: str) -> Optional[str]:
     """
